OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Muuda taastevõtme salasõna",
    "Please repeat the recovery key password" : "Palun korda uut taastevõtme salasõna",
    "Repeated recovery key password does not match the provided recovery key password" : "Teistkorda sisestatud taastevõtme salasõna ei kattu sisestatud taastevõtme salasõnaga",
    "Recovery key successfully enabled" : "Taastevõtme lubamine õnnestus",
    "Could not enable recovery key. Please check your recovery key password!" : "Ei suutnud taastevõtit kasutusele võtta. Palun kontrolli oma taastevõtme salasõna!",
    "Recovery key successfully disabled" : "Taastevõtme keelamine õnnestus",
    "Could not disable recovery key. Please check your recovery key password!" : "Ei suutnud taastevõtme kasutamist lõpetada. Palun kontrolli oma taastevõtme salasõna!",
    "Please provide the old recovery password" : "Palun sisesta vana taastevõtme salasõna",
    "Please provide a new recovery password" : "Palun sisesta uus taastevõtme salasõna",
    "Please repeat the new recovery password" : "Palun korda uut taastevõtme salasõna",
    "Password successfully changed." : "Salasõna vahetamine õnnestus.",
    "Could not change the password. Maybe the old password was not correct." : "Ei suutnud muuta salasõna. Võib-olla on vana salasõna valesti sisestatud.",
    "Recovery Key disabled" : "Taastevõti on välja lülitatud",
    "Recovery Key enabled" : "Taastevõti on sisse lülitatud",
    "Could not enable the recovery key, please try again or contact your administrator" : "Taastevõtme ksutuselevõtmine ei õnnestunud, palun proovi hiljem uuesti või võta ühendust serveri haldajaga",
    "Could not update the private key password." : "Ei suutnud uuendada privaatvõtme salasõna.",
    "The old password was not correct, please try again." : "Vana salasõna polnud õige, palun proovi uuesti.",
    "The current log-in password was not correct, please try again." : "Sisselogimise senine salasõna polnud õige, palun proovi uuesti.",
    "Private key password successfully updated." : "Privaatvõtme salasõna uuendamine õnnestus.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Krüptimisrakenduse vigane privaatvõti. Taastamaks ligipääsu krüptitud failidele palun uuenda oma isiklikest seadistustest privaatvõtme salasõna.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Krüptimisrakendus on kasutusel, kuid krüptovõtmed pole valmendatud. Palun logi välja ning uuesti sisse.",
    "Encryption app is enabled and ready" : "Krüptimisrakendus on kasutusel ja töövalmis",
    "Bad Signature" : "Vigane allkiri",
    "Missing Signature" : "Allkiri puudub",
    "one-time password for server-side-encryption" : "ühekordne salasõna serveripoolse krüptimise jaoks",
    "Encryption password" : "Krüptimise salasõna",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "Serveri peakasutaja lülitas sisse serveripoolse krüptimise. Sinu failid on krüptitud salasõnaga <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "Serveri peakasutaja lülitas sisse serveripoolse krüptimise. Sinu failid on krüptitud salasõnaga „%s“.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Selle faili dekrüptimine ei õnnestu. Ilmselt on tegemist jagatud failiga. Palu omanikul seda faili sinuga uuesti jagada.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Selle faili lugemine ei õnnestu. Ilmselt on tegemist jagatud failiga. Palu omanikul seda faili sinuga uuesti jagada.",
    "Default Encryption Module" : "Vaikimisi krüptomoodul",
    "Default encryption module for Nextcloud Server-side Encryption (SSE)" : "Vaikimisi krüptomoodul Nextcloudi serveripoolse krüptimise jaoks (SSE)",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Selle valiku kasutamisel krüptitakse failid sisemises ja välises andmeruumis. Vastasel juhul vaid välises andmeruumis.",
    "Encrypt the home storage" : "Krüpti ka sisemine andmeruum",
    "Disable recovery key" : "Keela taastevõtme kasutamine",
    "Enable recovery key" : "Luba taastevõtme kasutamine",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "Taastevõti on täiendav krüptovõti, mida kasutatakse failide krüptimisel. Kui peaksid põhilise salasõna unustama, siis saad seda failide taastamisel kasutada. Salvesta ta turvaliselt digitaalsesse salasõnalaekasse või vana kooli seifi.",
    "Recovery key password" : "Taastevõtme salasõna",
    "Passwords fields do not match" : "Salasõnad ei klapi",
    "Repeat recovery key password" : "Korda taastevõtme salasõna",
    "An error occurred while updating the recovery key settings. Please try again." : "Taastevõtme seadistuste muutmisel tekkis viga. Palun proovi uuesti.",
    "Change recovery key password" : "Muuda taastevõtme salasõna",
    "Old recovery key password" : "Vana taastevõtme salasõna",
    "New recovery key password" : "Uus taastevõtme salasõna",
    "Repeat new recovery key password" : "Korda uut taastevõtme salasõna",
    "An error occurred while changing the recovery key password. Please try again." : "Taastevõtme salasõna muutmisel tekkis viga. Palun proovi uuesti.",
    "Update private key password" : "Uuenda privaatvõtme salasõna",
    "Your private key password no longer matches your log-in password. Set your old private key password to your current log-in password." : "Sinu privaatvõtme salasõna enam ei vasta sinu kasutajakonto salasõnale (seda kasutad sisselogimisel). Palun muuda privaatvõtme salasõna kasutajakontoga samaks.",
    "If you do not remember your old password you can ask your administrator to recover your files." : "Kui sa ei mäleta oma vana salasõna, siis palu oma süsteemihalduril taastada ligipääs failidele.",
    "Old log-in password" : "Sisselogimise vana salasõna",
    "Current log-in password" : "Sisselogimise praegune salasõna",
    "Update" : "Uuenda",
    "Updating recovery keys. This can take some time…" : "Uuendan taastevõtmeid. Selleks võib kuluda natuke aega…",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Valiku lubamine võimaldab salasõna kaotamise korral taastada ligipääsu krüptitud failidele",
    "Enable password recovery" : "Võta salasõnade taastamine kasutusele",
    "Default encryption module" : "Vaikimisi krüptimismoodul",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Krüptimisrakendus on kasutusel, kuid krüptovõtmed pole valmendatud. Palun logi välja ning uuesti sisse.",
    "Basic encryption module" : "Lihtkrüptimise moodul",
    "Missing parameters" : "Parameetrid puuduvad",
    "Default encryption module for server-side encryption" : "Vaikimisi krüptimismoodul serveripoolse krüptimise jaoks",
    "Change recovery key password:" : "Muuda taastevõtme salasõna:",
    "Change Password" : "Muuda salasõna",
    "Your private key password no longer matches your log-in password." : "Sinu privaatvõtme salasõna ei kattu enam sinu sisselogimise salasõna.",
    "Set your old private key password to your current log-in password:" : "Pane oma vana privaatvõtme salasõnaks oma praegune sisselogimise salasõna.",
    "Update Private Key Password" : "Uuenda privaatvõtme salasõna",
    "Enable password recovery:" : "Luba salasõna taastamine:",
    "Enabled" : "Sisse lülitatud",
    "Disabled" : "Välja lülitatud"
},
"nplurals=2; plural=(n != 1);");
